@@ -40,6 +40,7 @@ struct field_s {
     void (*mul)(element_ptr, element_ptr, element_ptr);
     void (*mul_mpz)(element_ptr, element_ptr, mpz_ptr);
     void (*mul_si)(element_ptr, element_ptr, signed long int);
+    void (*div)(element_ptr, element_ptr, element_ptr);
     void (*square)(element_ptr, element_ptr);
     int (*is_sqr)(element_ptr);
     void (*sqrt)(element_ptr, element_ptr);
@@ -49,7 +50,7 @@ struct field_s {
     void (*invert)(element_ptr, element_ptr);
     void (*neg)(element_ptr, element_ptr);
     void (*random)(element_ptr);
-    void (*from_hash)(element_ptr, int len, void *data);
+    void (*from_hash)(element_ptr, void *data, int len);
     int (*is1)(element_ptr);
     int (*is0)(element_ptr);
     int (*sign)(element_ptr); //satisfies sign(x) = -sign(-x)
@@ -61,7 +62,7 @@ struct field_s {
     mpz_t order; //0 for infinite order
     element_ptr nqr; //nonquadratic residue
     void (*to_mpz)(mpz_ptr, element_ptr);
-    void (*print_info)(FILE *, struct field_s *);
+    void (*out_info)(FILE *, struct field_s *);
     void (*pp_init)(element_pp_t p, element_t in);
     void (*pp_clear)(element_pp_t p);
     void (*pp_pow)(element_t out, mpz_ptr power, element_pp_t p);
@@ -88,7 +89,7 @@ lies in.
 */
 static inline void element_init_same_as(element_t e, element_t e2)
 {
-    e2->field->init(e);
+    element_init(e, e2->field);
 }
 
 /*@manual einit
@@ -184,9 +185,9 @@ static inline void element_to_mpz(mpz_t z, element_t e)
 Generate an element ''e'' deterministically from
 the ''len'' bytes stored in the buffer ''data''.
 */
-static inline void element_from_hash(element_t e, int len, void *data)
+static inline void element_from_hash(element_t e, void *data, int len)
 {
-    e->field->from_hash(e, len, data);
+    e->field->from_hash(e, data, len);
 }
 /*@manual earith
 Set ''n'' to ''a'' + ''b''.
@@ -243,6 +244,14 @@ static inline void element_mul_zn(element_t c, element_t a, element_t z)
     mpz_clear(z0);
 }
 
+/*@manual earith
+Set ''n'' to ''a'' / ''b''.
+*/
+static inline void element_div(element_t n, element_t a, element_t b)
+{
+    n->field->div(n, a, b);
+}
+
 /*@manual earith
 Set ''n'' to ''a'' + ''a''.
 */
@@ -508,7 +517,7 @@ Currently only implemented for points on an elliptic curve.
 */
 int element_length_in_bytes_compressed(element_t e);
 
-void field_print_info(FILE *out, field_ptr f);
+void field_out_info(FILE *out, field_ptr f);
 
 /*@manual epow
 Prepare to exponentiate an element ''in'', and store preprocessing information
@@ -541,4 +550,8 @@ void pbc_mpz_out_raw_n(unsigned char *data, int n, mpz_t z);
 void pbc_mpz_from_hash(mpz_t z, mpz_t limit,
 	unsigned char *data, unsigned int len);
 
+void brute_force_dlog(element_t x, element_t g, element_t h);
+void pollard_rho(element_t x, element_t g, element_t h);
+void index_calculus_dlog(mpz_t x, mpz_t g, mpz_t h, mpz_t q);
+
 #endif //FIELD_H
